@@ -26,7 +26,7 @@ int notcurses_inputready_fd(struct notcurses* n);
 typedef struct cell {
   uint32_t gcluster;          // 4B → 4B
   uint8_t gcluster_backstop;  // 1B → 5B (8 bits of zero)
-  uint8_t width;              // 1B → 6B (8 bits, width biased-1)
+  uint8_t width;              // 1B → 6B (8 bits, width)
   uint16_t stylemask;         // 2B → 8B (16 bits of NCSTYLE_* attributes)
   uint64_t channels;          // + 8b == 16b
 } cell;
@@ -413,16 +413,16 @@ int ncplane_putnstr_yx(struct ncplane* n, int y, int x, size_t s, const char* gc
 int ncplane_putnstr_aligned(struct ncplane* n, int y, ncalign_e align, size_t s, const char* gclustarr);
 int ncplane_qrcode(struct ncplane* n, ncblitter_e blitter, int* ymax, int* xmax, const void* data, size_t len);
 struct ncdirect* ncdirect_init(const char* termtype, FILE* fp, uint64_t flags);
-int ncdirect_bg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
-int ncdirect_fg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
+int ncdirect_set_bg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
+int ncdirect_set_fg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
 unsigned ncdirect_palette_size(const struct ncdirect* nc);
 int ncdirect_putstr(struct ncdirect* nc, uint64_t channels, const char* utf8);
 int ncdirect_printf_aligned(struct ncdirect* n, int y, ncalign_e align, const char* fmt, ...);
-int ncdirect_fg_rgb(struct ncdirect* n, unsigned rgb);
-int ncdirect_bg_rgb(struct ncdirect* n, unsigned rgb);
-int ncdirect_styles_set(struct ncdirect* n, unsigned stylebits);
-int ncdirect_styles_on(struct ncdirect* n, unsigned stylebits);
-int ncdirect_styles_off(struct ncdirect* n, unsigned stylebits);
+int ncdirect_set_fg_rgb(struct ncdirect* n, unsigned rgb);
+int ncdirect_set_bg_rgb(struct ncdirect* n, unsigned rgb);
+int ncdirect_set_styles(struct ncdirect* n, unsigned stylebits);
+int ncdirect_on_styles(struct ncdirect* n, unsigned stylebits);
+int ncdirect_off_styles(struct ncdirect* n, unsigned stylebits);
 int ncdirect_clear(struct ncdirect* n);
 int ncdirect_stop(struct ncdirect* n);
 int ncdirect_dim_x(const struct ncdirect* nc);
